==> openurp-edu-base-adminapp-0.0.26-sources.jar: org/openurp/edu/base/web/action/MajorDisciplineAction.scala <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.edu.base.web.action

import org.beangle.data.dao.OqlBuilder
import org.beangle.data.model.Entity
import org.beangle.webmvc.api.annotation.action
import org.beangle.webmvc.entity.action.RestfulAction
import org.openurp.code.edu.model.DisciplineCategory
import org.openurp.edu.base.model.{ Major, MajorDiscipline }

/**
 * @author xinzhou
 */
class MajorDisciplineAction extends RestfulAction[MajorDiscipline] {

  override def editSetting(entity: MajorDiscipline) {
    put("majors", findItems(classOf[Major]))
    put("categories", findItems(classOf[DisciplineCategory]))

  }
  private def findItems[T <: Entity[_]](clazz: Class[T]): Seq[T] = {
    val query = OqlBuilder.from(clazz)
    query.orderBy("name")
    val items = entityDao.search(query)
    items
  }
}

==> openurp-edu-base-adminapp-0.0.30-sources.jar: org/openurp/edu/base/web/action/MajorDisciplineAction.scala <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.edu.base.web.action

import org.beangle.data.dao.OqlBuilder
import org.beangle.data.model.Entity
import org.beangle.webmvc.api.annotation.action
import org.beangle.webmvc.entity.action.RestfulAction
import org.openurp.code.edu.model.DisciplineCategory
import org.openurp.edu.base.model.{Major, MajorDiscipline}

/**
 * @author xinzhou
 */
class MajorDisciplineAction extends RestfulAction[MajorDiscipline] {

  override def editSetting(entity: MajorDiscipline): Unit = {
    put("majors", findItems(classOf[Major]))
    put("categories", findItems(classOf[DisciplineCategory]))
  }

  private def findItems[T <: Entity[_]](clazz: Class[T]): Seq[T] = {
    val query = OqlBuilder.from(clazz)
    query.orderBy("name")
    val items = entityDao.search(query)
    items
  }
}
